/*
 *
 * Copyright(C) OASIS(R) 2009,2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 *   
 */
package org.oasisopen.sca.test;

import java.util.Collection;

import org.oasisopen.sca.annotation.*;
import org.oasisopen.sca.test.Service1;


/**
 * Java component implementation with
 * 1 service with interface Service1, no @Service annotation
 * 1 reference "reference1" (1..n) with interface Service1, no @Reference annotation
 * all wired references get called when service1 operation1 is invoked
 * 
 * The class has no @Service, @Property and @Reference annotations but it has a setter method
 * which has a parameter which is an collection typed by an interface which has a @Remotable annotation
 */
public class Service1UnannotatedMultiRefCollSetterImpl implements Service1 {
	
	private String serviceName = "service1";
	private Collection<Service1> reference1 = null;

	public String operation1(String input) {
		String result = serviceName + " operation1 invoked";
		// Call each of the references in the array, concatenating the results
		for( Service1 reference : reference1 ) {
			result = result.concat(" ");
			result = result.concat( reference.operation1(input) );
		} // end for
		return result;
	}
	
	/**
	 * Setter for a property with the name "serviceName"
	 * @param aServiceName - the service name
	 */
	public void setServiceName( String aServiceName ) {
		serviceName = aServiceName;
	}
	
	/**
	 * Setter for a reference with the name "reference1"
	 * @param aReference - the reference proxy array
	 */
	public void setReference1( Collection<Service1> aReference ) {
		reference1 = aReference;
	}

} // Service1UnannotatedMultiRefCollSetterImpl
