/*
 * Copyright(C) OASIS(R) 2009,2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 */
package client_javapojo;

import org.junit.Test;
import org.junit.Ignore;

import client.BaseJAXWSTestRunner;
import client.TestConfiguration;
import testClient.TestInvocation;

/**
 * Client for POJO_10007_TestCase
 * Tests that all Java classes loaded from a Contribution are loaded by a class loader that is 
 * unique to the contribution
 */
/**
 * The design of this testcase is that the top level composite sits in Contribution POJO_10007 and contains
 * a component with a POJO implementation class X, which provides a service with an interface class Y and
 * the interface class has a method with a parameter which is of class Z. Classes X, Y, Z are all in
 * different Java packages
 * Contribution POJO_10007 contains no Java classes and contains 3 <import.java/> elements one for each of
 * the packages associated with classes X, Y and Z.
 * Contribution B contains the classes X and Y and has <export.java/> elements for each of their
 * packages plus an <import.java/> for the package of class Z
 * Contribution C contains the class Z and an <export.java/> element for the package of class Z
 * 
 * The test involves the invocation of the component implementation X through the service typed by Y.
 * On invocation, X first compares the classloader of X with the classloader of Y and expects equality
 * then X compares the classloader of X with the classloader of Z and expects inequality - X reports
 * its findings in the response to the invoked operation.
 */
public class POJO_10007_TestCase extends BaseJAXWSTestRunner {

    protected TestConfiguration getTestConfiguration() {
    	TestConfiguration config = new TestConfiguration();
    	config.testName 		 = "POJO_10007";
    	config.input 		 	 = "request";
    	config.output[0] 		 = "POJO_10007 request service1 operation1 invoked service2 operation1 invoked" + 
    	                           " Service interface classloader same as Impl class classloader" + 
    	                           " ComplexClass classloader different from Impl class classloader";
    	config.composite 		 = "Test_" + config.testName + ".composite";
    	config.testServiceName 	 = "TestClient";
    	config.contributionNames = new String[] { "POJO_10007", "POJO_ContributionE", "POJO_ContributionF", "POJO_General" };
    	config.serviceInterface  = TestInvocation.class;
    	return config;
    }
    
    /**
     * Dummy method to ensure that things work with JUnit 3 eg within Eclipse Ganymede
     */
    @Ignore
    @Test
    public void testFoo() throws Exception {  	
    }
    
} // end class Test_POJO_10007
