/*
 *
 * Copyright(C) OASIS(R) 2009,2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 *     
 */
package org.oasisopen.sca.test;

import org.oasisopen.sca.annotation.*;
import org.oasisopen.sca.test.Service1;


/**
 * Java component implementation with
 * 1 service with interface Service1
 * 1 reference (1..n) with interface Service1
 * all configured wires get called when service1 operation1 is invoked
 * 
 * This implementation acts as a coordinator between each of the invocations
 * - it sends different data as input to each reference invocation
 * - it records all the output data from all the invocations
 *
 */
@Service(Service1.class)
public class service1CoordinatorImpl implements Service1 {
	
	@Property
	public String serviceName = "service1";
	@Property
	public int invocationCount = 0;
	// Required = true + an array -> multiplicity 1..1
	@Reference(required=true)
	public Service1 reference1 = null;

	public String operation1(String input) {
		String result = "";
		
		// Deal with the case where the reference has no targets supplied...
		// Should this throw an exception?
		if( reference1 == null ) {
			return serviceName + " error: reference 'reference1' has no target";
		} // end if
		
		// Call each of the references in the array, concatenating the results
		String resultStem = "serviceComposite operation1 ";
		String expectedResult = resultStem + "Initial";
		for( int i=0 ; i < invocationCount; i++ ) {
			result = reference1.operation1(Integer.toString(i+1));
			if( !expectedResult.equals(result) ) return serviceName + " operation1 invoked" +
			  " target composite scope service failed test";
			// The composite scope service stores the input to one invocation and returns it as
			// the result of the NEXT invocation
			expectedResult = resultStem + Integer.toString(i+1);
		} // end for
		return serviceName + " operation1 invoked" + " target composite scope service invoked successfully";
	}

}
