/*
 * Copyright(C) OASIS(R) 2009,2010. All Rights Reserved.
 * OASIS trademark, IPR and other policies apply.    
 */
package client_javapojo;

import org.junit.Test;
import org.junit.Ignore;

import client.BaseJAXWSTestRunner;
import client.TestConfiguration;
import testClient.TestInvocation;

/**
 * Client for POJO_10008_TestCase
 * Tests that where a contribution A uses one or more Java classes that are imported from 
 * a contribution B, that contribution B's classloader is used to load the classes imported 
 * into contribution A
 */
/**
 * In the design of this testcase, "contribution A" is the contribution POJO_10008 and
 * "contribution B" is the contribution POJO_ContributionE
 * 
 * POJO_10008 contains the top level composite Test_POJO_10008.composite
 * - contains component 1 implemented by a POJO class that is contained in POJO_10008 contribution
 * - contains component 2 implemented by a composite that is contained in POJO_ContributionE
 * - component 1 has a reference that is wired to a service provided by component 2
 * - the service interface of the reference and the service is defined by a class contained in
 * POJO_ContributionE
 * 
 * POJO_ContributionE contains the second composite and this composite contains a component which
 * implements the service offered by component 2
 * - the POJO class for this component is contained in POJO_ContributionE
 * 
 * When component 1 invokes component 2, it does it using an operation that returns the hashcode of 
 * the ClassLoader used to load the implementation of component 2 - component 1 compares this with:
 * a) the hashcode of the classloader for its implementation class (should be different)
 * b) the hashcode of the classloader for the service interface class (should be the same)
 */
public class POJO_10008_TestCase extends BaseJAXWSTestRunner {

    protected TestConfiguration getTestConfiguration() {
    	TestConfiguration config = new TestConfiguration();
    	config.testName 		 = "POJO_10008";
    	config.input 		 	 = "request";
    	config.output[0] 		 = "POJO_10008 request service1 operation1 invoked classloaders set correctly";
    	config.composite 		 = "Test_" + config.testName + ".composite";
    	config.testServiceName 	 = "TestClient";
    	config.contributionNames = new String[] { "POJO_10008", "POJO_ContributionE", "POJO_ContributionF", "POJO_General" };
    	config.serviceInterface  = TestInvocation.class;
    	return config;
    }
    
    /**
     * Dummy method to ensure that things work with JUnit 3 eg within Eclipse Ganymede
     */
    @Ignore
    @Test
    public void testFoo() throws Exception {  	
    }
    
} // end class Test_POJO_10008
